aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
-rwxr-xr-xcopy.sh6
1 files changed, 3 insertions, 3 deletions
diff --git a/copy.sh b/copy.sh
index a12dc13a..08dd1e9d 100755
--- a/copy.sh
+++ b/copy.sh
@@ -36,8 +36,8 @@ print_color() {
printf "%b%s%b\n" "$1" "$2" "$CLEAR"
}
-# Check if dpkg is installed (use to check if Debian or Ubuntu or based distros)
-if command -v dpkg &> /dev/null; then
+# Check /etc/os-release to see if this is an Ubuntu or Debian based distro
+if grep -q '^\(ID_LIKE\|ID\)=.*\(debian\|ubuntu\)' /etc/os-release &> /dev/null; then
printf "\n%.0s" {1..1}
print_color $WARNING "
█▀▀▀▀▀▀▀▀▀▀▀▀▀▀▀▀▀▀▀▀▀▀▀▀▀▀▀▀▀▀▀▀▀▀▀▀▀▀▀▀▀▀▀▀▀▀▀▀▀▀▀▀▀█
@@ -851,4 +851,4 @@ printf "\n%.0s" {1..1}
printf "${INFO} However, it is ${MAGENTA}HIGHLY SUGGESTED${RESET} to logout and re-login or better reboot to avoid any issues"
printf "\n%.0s" {1..1}
printf "${SKY_BLUE}Thank you${RESET} for using ${MAGENTA}KooL's Hyprland Configuration${RESET}... ${YELLOW}ENJOY!!!${RESET}"
-printf "\n%.0s" {1..3} \ No newline at end of file
+printf "\n%.0s" {1..3}
send patches to the email below
yukais@pinapelz.com
include the subject [PATCH repo_name]
pinapelz.com
homepage